==> haskell-vector-stream-0.1.0.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-stream.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vector-stream
version:              0.1.0.0
visibility:           public
id:                   vector-stream-0.1.0.0-4waQ7Ba3DNc332rFgBcrBU
key:                  vector-stream-0.1.0.0-4waQ7Ba3DNc332rFgBcrBU
license:              BSD-3-Clause
copyright:
    (c) Roman Leshchinskiy 2008-2012
    Alexey Kuleshevich 2020-2022,
    Aleksey Khudyakov 2020-2022,
    Andrew Lelechenko 2020-2022

maintainer:           Haskell Libraries Team <libraries@haskell.org>
author:               Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage:             https://github.com/haskell/vector
synopsis:             Efficient Streams
description:
    Simple yet powerful monadic streams that are used
    as a backbone for vector package fusion functionality.

category:             Data, Data Structures
abi:                  1ab81b627d034e62a746bee6646f5cd2
exposed:              True
exposed-modules:      Data.Stream.Monadic
import-dirs:          /usr/lib/ghc-9.0.2/site-local/vector-stream-0.1.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/vector-stream-0.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-stream
hs-libraries:         HSvector-stream-0.1.0.0-4waQ7Ba3DNc332rFgBcrBU
depends:              base-4.15.1.0 ghc-prim-0.7.0
haddock-interfaces:
    /usr/share/doc/haskell-vector-stream/html/vector-stream.haddock

haddock-html:         /usr/share/doc/haskell-vector-stream/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vector-stream-0.1.0.1-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-vector-stream.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vector-stream
version:              0.1.0.1
visibility:           public
id:                   vector-stream-0.1.0.1-IpszUhptPKS1rgc741JEdV
key:                  vector-stream-0.1.0.1-IpszUhptPKS1rgc741JEdV
license:              BSD-3-Clause
copyright:
    (c) Roman Leshchinskiy 2008-2012
    Alexey Kuleshevich 2020-2022,
    Aleksey Khudyakov 2020-2022,
    Andrew Lelechenko 2020-2022

maintainer:
    Haskell Libraries Team <libraries@haskell.org>
    Alexey Kuleshevich <alexey@kuleshevi.ch>,
    Aleksey Khudyakov <alexey.skladnoy@gmail.com>,
    Andrew Lelechenko <andrew.lelechenko@gmail.com>

author:               Roman Leshchinskiy <rl@cse.unsw.edu.au>
homepage:             https://github.com/haskell/vector
synopsis:             Efficient Streams
description:
    Simple yet powerful monadic streams that are used
    as a backbone for vector package fusion functionality.

category:             Data, Data Structures
abi:                  90d603be05ac90b4d893b7d761b3259e
exposed:              True
exposed-modules:      Data.Stream.Monadic
import-dirs:          /usr/lib/ghc-9.0.2/site-local/vector-stream-0.1.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/vector-stream-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vector-stream
hs-libraries:         HSvector-stream-0.1.0.1-IpszUhptPKS1rgc741JEdV
depends:              base-4.15.1.0 ghc-prim-0.7.0
haddock-interfaces:
    /usr/share/doc/haskell-vector-stream/html/vector-stream.haddock

haddock-html:         /usr/share/doc/haskell-vector-stream/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
